@@ -3,10 +3,7 @@ import importlib
 def schedule(card):
 
 	if card.last_grade == -1:
-		card.set_due_date('deleted')
-		return 0
-	elif card.last_grade == -2:
-		card.set_due_date('suspended')
+		card.delete()
 		return 0
 
 	# import the specific scheduler module
